@@ -7,12 +7,12 @@ _netid_to_name = {
 
 _contract_addresses_proxy_v1 = {
     "mumbai": {
-        "StableToken": "0x27f43eF37bc44120eDD91626f40C6DFa8908300C",
-        "Manager": "0x25074928fA2cDd06Fb9f0902d710f7EDB494dbe2",
-        "Amm_eth-usdc": "0x9e7225628bB6f9F437F123287602f59d705c8AA1",
-        "Amm_btc-usdc": "0x40Ff56e22D26B41F13f79D61311e7DA605C0c4c2",
-        "Amm_matic-usdc": "0xaB0BcF1F2f24145EcB2EAF3A11B8E1A25A839de7",
-        "AmmReader": "0x410325f7A08FD56374a822db318E2593c9e5F5C8"
+        "StableToken": "0x2E4c42aB89E8f928C74571Bb54C2DaA28605937B",
+        "Manager": "0xc7Bf6E9a1EE40EB452712F219Ffd57D0feE0691c",
+        "Amm_eth-usdc": "0x9fFeBA1A8cD88D0BDb996Cf75A993fdAfEE8f4f6",
+        "Amm_btc-usdc": "0xec8c5521c4Df81be57436a5DC9e2Ac4C888E0054",
+        "Amm_matic-usdc": "0x74456feE1Cf361787EA0545B7f075A72084a3965",
+        "AmmReader": "0x314426488153C2867Dbb1FC1dee3B406F9E3c7B0"
     },
     "local": {
         "StableToken": "0x5FbDB2315678afecb367f032d93F642f64180aa3",
@@ -24,13 +24,13 @@ _contract_addresses_proxy_v1 = {
     },
     "matic": {
         "StableToken": "0x2791bca1f2de4661ed88a30c99a7a9449aa84174",            
-        "Manager": "0x84B056EB1107f8F8B127a57De0222A8A211C1e42",
-        "Amm_eth-usdc": "0x80081DD1EEedbc8631c3077D4204bEa7270de891",
-        "Amm_btc-usdc": "0xAE6dFb1923052890a077A135498F2B34A40F69Cc",
-        "Amm_matic-usdc": "0x07429D7fDd2651d2712D87fd434669B1908dd5DA",
-        "Amm_sol-usdc": "0xa23Ac746740cfE9013d94e62f7b0f1376EdCa759",
-        "Amm_dot-usdc": "0x6F88D5D707908e961228C4708D19a6252B546e13",
-        "AmmReader": "0x3e33b0FefD9C1886bd07C3308212f0f4a7c4A38d"
+        "Manager": "0x6D171813A179520Dc5f1F62a699940eC537730F4",
+        "Amm_eth-usdc": "0x44ecda99159270f6e2a328d3ae03d0aa2e4c6e89",
+        "Amm_btc-usdc": "0x017af3e292554580671c6cf51321d2eda64de862",
+        "Amm_matic-usdc": "0x2b538e01c3686d4a0a38657106c0cf442c74979f",
+        "Amm_sol-usdc": "0x355b5f5a394ca7058bb853879cce8e5b13167432",
+        "Amm_dot-usdc": "0x26691b6e1cb0f908926149fa58326ad4966d0aa5",
+        "AmmReader": "0xe3774bF2EAc6716e1ef67B77AEcd6eBB3A2f84Ca"
     }
 }
 
