@@ -1,5 +1,7 @@
 import os, sys
 import time
+import ast
+import json
 from datetime import datetime
 import logging
 from typing import Any, Optional, Union, Dict
@@ -197,8 +199,9 @@ class Polysynth:
                     abi_name="Amm_" + amm.split("-")[0].upper(),
                     address=_str_to_addr(amm_contract_addr),
                 )
+            _rev_side = 1 if _side_str_to_int(side) == 0 else 0
             price = amm_contract.functions.getOutputPrice(
-                _side_str_to_int(side),
+                _rev_side,
                 _int_to_bignum(baseAssetAmount)
             ).call()
             return Response(StatusCode.OK.value, None, None, data= { "amount": abs(_normalize(price[0])) }).__dict__()
@@ -237,6 +240,8 @@ class Polysynth:
             _amm_contract_addr = _amm_name_to_addr(amm, self.network)
             _side = _side_str_to_int(side)
             _quote_asset_limit = self._quote_asset_limit(amm, quoteAssetAmount, leverage, _side, slippage)
+            _size = _normalize(self._input_price(amm, side, quoteAssetAmount)[0])
+            _price = (quoteAssetAmount*leverage)/_size
 
             manager = self.manager_contract.functions
             tx_params = self._get_tx_params()
@@ -267,12 +272,14 @@ class Polysynth:
             position = self._trader_position(amm)
             if position[0] == 0:
                 raise NoPositionsOpen(StatusCode.OK.value, StatusCode.ZERO_COLLATERAL.value, ErrorMessage.NO_POSITIONS_OPEN.value)
-            _price = round(position[2]/position[0], 4)
-            _size = _normalize(position[0])
+            # _price = round(position[2]/position[0], 4)
+            # _size = _normalize(position[0])
+            
             _side = "BUY" if _size > 0 else "SELL"
-            _leverage = round(position[2]/position[1], 4)
+            # _leverage = round(position[2]/position[1], 4)
 
             _collateral_ratio = _normalize(self._collateral_ratio(amm))
+            _leverage = round(1/_collateral_ratio, 4)
 
             result = OpenPositionRes(_price, _side, _size, _leverage, _collateral_ratio, tx).__dict__()
 
@@ -377,12 +384,14 @@ class Polysynth:
             time.sleep(1)
             # get trader's new leverage and margin
             position = self._trader_position_with_funding_payment(amm)
-            new_collateral, new_leverage = _normalize(position[1]), round(position[2]/position[1], 4)
+            # new_collateral, new_leverage = _normalize(position[1]), round(position[2]/position[1], 4)
+            new_collateral = _normalize(position[1])
 
             _unrealized_pnl = _normalize(self._unrealized_pnl(amm))
             _margin_after = new_collateral + _unrealized_pnl
 
             ratio = _normalize(self._collateral_ratio(amm))
+            new_leverage = round(1/ratio, 4)
             result = MarginRes(_margin_after, new_leverage, ratio, tx).__dict__()
 
             return Response(StatusCode.OK.value, None, None, data=result).__dict__()
@@ -408,17 +417,22 @@ class Polysynth:
         try:
             amm_contract_addr = _amm_name_to_addr(amm, self.network) # for eg resolves to Amm_eth
             # check if value doesn't exceed trader's collateral
-            _position_curr = self._trader_position_with_funding_payment(amm)
-            _collateral = _normalize(_position_curr[1])
-            _unrealized_pnl = _normalize(self._unrealized_pnl(amm))
-
-            _margin_ratio_curr = _normalize(self._collateral_ratio(amm))
-            _margin = _collateral + _unrealized_pnl
-
-            _collateral_ratio_after = ( _margin - collateral ) / ( _margin/_margin_ratio_curr )
-
-            if _collateral_ratio_after < 0.0625:
+            position = self._trader_position(amm)
+            
+            _collateral_after = _normalize(position[1]) - collateral
+            if _collateral_after < 0:
                 raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.COLLATERAL_NOT_ENOUGH.value, ErrorMessage.COLLATERAL_NOT_ENOUGH.value)
+            # _position_curr = self._trader_position_with_funding_payment(amm)
+            # _collateral = _normalize(_position_curr[1])
+            # _unrealized_pnl = _normalize(self._unrealized_pnl(amm))
+
+            # _margin_ratio_curr = _normalize(self._collateral_ratio(amm))
+            # _margin = _collateral + _unrealized_pnl
+
+            # _collateral_ratio_after = ( _margin - collateral ) / ( _margin/_margin_ratio_curr )
+
+            # if _collateral_ratio_after < 0.0625:
+            #     raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.COLLATERAL_NOT_ENOUGH.value, ErrorMessage.COLLATERAL_NOT_ENOUGH.value)
 
             manager = self.manager_contract.functions
             func_params = [
@@ -442,12 +456,14 @@ class Polysynth:
                     data = {"tx_hash": receipt.hex()}).__dict__()
 
             position = self._trader_position_with_funding_payment(amm)
-            new_collateral, new_leverage = _normalize(position[1]), round(position[2]/position[1], 4)
+            # new_collateral, new_leverage = _normalize(position[1]), round(position[2]/position[1], 4)
+            new_collateral = _normalize(position[1])
 
             _unrealized_pnl = _normalize(self._unrealized_pnl(amm))
             _margin_after = new_collateral + _unrealized_pnl
 
             ratio = _normalize(self._collateral_ratio(amm))
+            new_leverage = round(1/ratio, 4)
             result = MarginRes(_margin_after, new_leverage, ratio, tx).__dict__()
             return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except ContractLogicError as e:
@@ -772,7 +788,9 @@ class Polysynth:
 
                 if size == 0 or collateral == 0: continue
 
-                leverage = round(position[2]/position[1], 4)
+                # leverage = round(position[2]/position[1], 4)
+                _collateral_ratio = _normalize(self._collateral_ratio(amm))
+                leverage = round(1/_collateral_ratio, 4)
                 avg_entry_price = round(position[2]/position[0], 4)
 
                 position_with_funding_payment = self._trader_position_with_funding_payment(amm)
@@ -882,7 +900,7 @@ class Polysynth:
                     ErrorMessage.TRANSACTION_PENDING.value,
                     data = {"tx_hash": receipt.hex()}).__dict__()
         except Exception as e:
-            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.TRANSACTION_NOT_CANCELLED.value, str(e).replace("\\", r"\\")).__dict__()
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.TRANSACTION_NOT_CANCELLED.value, ast.literal_eval(str(e))).__dict__()
 
     def retry_transaction(self, tx_hash: str) -> Any:
         try:
@@ -917,7 +935,7 @@ class Polysynth:
                     data = {"tx_hash": receipt.hex()}).__dict__()
 
         except Exception as e:
-            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.RETRY_FAILED.value, str(e).replace("\\", r"\\")).__dict__()
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.RETRY_FAILED.value, ast.literal_eval(str(e))).__dict__()
 
     def get_transaction_status(self, tx_hash: str) -> Any:
         try:
@@ -926,7 +944,8 @@ class Polysynth:
                 "tx_hash": receipt["transactionHash"].hex(),
                 "gas_fees": receipt["gasUsed"],
                 "block_number": receipt["blockNumber"],
-                "status": receipt["status"]
+                "status": receipt["status"],
+                "message": "Transaction Successful" if receipt["status"] == 1 else "Transaction Reverted"
             }
             return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except Exception as e:
@@ -940,7 +959,7 @@ class Polysynth:
             _check_slippage(slippage)
             
             # check wallet balance
-            self._check_wallet(quoteAssetAmount, leverage)
+            # self._check_wallet(quoteAssetAmount, leverage)
             # check price impact
             self._check_fluctuation(amm, quoteAssetAmount, leverage, _side)
         except TypeError:
