@@ -10,10 +10,10 @@ AddressLike = Union[Address, ChecksumAddress]
 
 class Response(object):
   def __init__(self, status_code, err_code, err_msg, data=None, **kwargs):
-    self._status_code = status_code
-    self._err_msg = err_msg if err_msg else ""
-    self._err_code = err_code if err_code else ""
-    self._data = data
+    self.status_code = status_code
+    self.err_msg = err_msg if err_msg else ''
+    self.err_code = err_code if err_code else ''
+    self.data = data if data else ''
 
     if 'leverage' in kwargs:
       self._data["leverage"] = kwargs["leverage"]
@@ -22,13 +22,16 @@ class Response(object):
 
   def __str__(self):
     return str({
-      "status_code": self._status_code,
-      "data" : self._data,
-      "error": {
-        "code": self._err_code,
-        "message": self._err_msg
+      'status_code': self.status_code,
+      'data': self.data,
+      'error': {
+        'code': self.err_code,
+        'message': self.err_msg
         }
     })
+  
+  def __dict__(self):
+    return json.loads(self.__str__().replace("'", '"'))
 
 class TraderPosition:
   def __init__(self, symbol, side, size, collateral, leverage, entry_price, margin, unrealized_pnl):
