@@ -8,7 +8,7 @@ from web3 import Web3
 from web3.exceptions import NameNotFound
 from polysynth.enum import ErrorMessage, StatusCode
 
-from polysynth.exception import InvalidFormatError, InvalidParameterError
+from polysynth.exception import InvalidFormatError, InvalidParameterError, TransactionFailedError
 
 from .types import AddressLike, Address, Contract
 from .constants import (
@@ -95,7 +95,7 @@ def _side_str_to_int(side: str) -> Any:
 def _amm_name_to_addr(amm: str, network: str) -> Any:
     try:
         amm_title = "Amm_" + amm.lower()
-        return _contract_addresses_proxy_v1[network][amm_title]
+        return Web3.toChecksumAddress(_contract_addresses_proxy_v1[network][amm_title])
     except:
         raise InvalidParameterError(StatusCode.BAD_REQUEST.value, StatusCode.UKNOWN_ADDRESS.value, ErrorMessage.INVALID_MARKET.value %amm)
 
@@ -136,12 +136,13 @@ def _normalize(amount: int):
     return round(amount/10**18, 7)
 
 def _estimate_gas_fee(_type: str, _network: str):
-    _url = None
-    if _network == "matic":
-        _url = "https://gasstation-mainnet.matic.network/v2"
-    elif _network == "mumbai":
-        _url = 'https://gasstation-mumbai.matic.today/v2'
-    res = requests.get(_url).json()
-
-    return res[_type]
-
+    try:
+        _url = None
+        if _network == "matic":
+            _url = "https://gasstation-mainnet.matic.network/v2"
+        elif _network == "mumbai":
+            _url = 'https://gasstation-mumbai.matic.today/v2'
+        res = requests.get(_url).json()
+        return res[_type]
+    except:
+        raise TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.CANNOT_FETCH_GAS_FEES.value, ErrorMessage.CANNOT_FETCH_GAS_FEES.value)
\ No newline at end of file
